pub fn update_font_database(font_root: &Utf8Path, db_url: &str) -> AppResult<()>Expand description
Updates the font database by scanning the provided root directory.
This function synchronizes the database with the disk, removes stale entries, parses new font files in parallel to extract family names, and inserts them into the database.
Best effort, fs open / mmap errors will be skipped.